% Radial thermal conductivity calculation
% FOURIERS LAW
% 
clc
close all
clear all
% INPUT
% measurement properties
dt = 1;          % time step
start = 3200;     % starting time thermal conductivity calculation 
startT = 1;      % starting time temperature plotter
% import data from measurements
%data  = xlsread('4.mai\0504.xlsx');
%data  = xlsread('27.april\0427_1.xlsx');
%data = xlsread('29.april\0429.xlsx');
%data = xlsread('6.mai\0506.xlsx');
%data = xlsread('11.mai\0511.xlsx');
%data = xlsread('25.mai\0525.xlsx');
%data = xlsread('26.mai\0526.xlsx');
%data = xlsread('27.mai\0527.xlsx');
%data = xlsread('28.mai\0528_1.xlsx');
data = xlsread('28.mai\0528_2.xlsx');
%data = xlsread('31.mai\0531.xlsx');
% use calibration results to remove deviation [T1 T2 T3]
T1 = 1.616;
T2 = 1.7179;
T3 = 1.7828;
T4 = 1.8413;

calibration = [T2 T3 T4];

% every measurement is the mean of n samples in front and end of the current time step
n = 10;

data2 = data;
for p = (n+1):1:(size(data,1)-(n+1))
    for q = 4:1:6
        sum = 0;
        for r = (p-n):1:(p+n)
            sum = sum + data(r,q);
        end
        data2(p,q) = sum/(2*n+1);
    end
end

%calibrate
data2(:,4) = data2(:,4)-calibration(1);
data2(:,5) = data2(:,5)-calibration(2);
data2(:,6) = data2(:,6)-calibration(3);

x = data2(start:dt:size(data,1),3);
T = [];
T(:,1) = data2(start:dt:size(data,1),4);
T(:,2) = data2(start:dt:size(data,1),5);
T(:,3) = data2(start:dt:size(data,1),6);

x2 = data2(startT:dt:size(data,1),3);
T2 = [];
T2(:,1) = data2(startT:dt:size(data,1),4);
T2(:,2) = data2(startT:dt:size(data,1),5);
T2(:,3) = data2(startT:dt:size(data,1),6);

% remove n+1 first and last rows in T matrix
for z = 1:1:n+1
    T(1,:)=[];
    T(size(T,1),:)=[];
    x(1,:)=[];
    x(length(x))=[];
    T2(1,:)=[];
    T2(size(T2,1),:)=[];
    x2(1,:)=[];
    x2(length(x))=[];
end

% radial position of each node [m]
r = [data(4,1) , data(5,1), data(6,1)]; 
% heat flux [W/m]
q = data(1,1);

k = []; % calculated conductivity

for i = 1:1:size(T,1)
    k(i,1) = -q/2/pi*log(r(2)/r(1))/(T(i,2)-T(i,1));
    k(i,2) = -q/2/pi*log(r(3)/r(2))/(T(i,3)-T(i,2));
    k(i,3) = -q/2/pi*log(r(3)/r(1))/(T(i,3)-T(i,1));
end

n = size(T,1);
T_mean = mean(T);
dT_mean = [T_mean(1)-T_mean(2), T_mean(2)-T_mean(3), T_mean(1)-T_mean(3)]
dT = [T(:,1)-T(:,2), T(:,2)-T(:,3), T(:,1)-T(:,3)];
S_square = [0 0 0];

for i = 1:n
    for j = 1:3
        S_square(j) = S_square(j) + (dT(i,j)-dT_mean(j))^2;
    end
end

S = sqrt(S_square/(n-1))
n
figure(1)

subplot(2,1,1),plot(x2,T2(:,1),'r',x2,T2(:,2),'b',x2,T2(:,3),'g')
xlabel('time [s]','fontsize',16)
ylabel('temperature [\circ C]','fontsize',16)
title('Temperature Development at Nodes','fontsize',16)
legend('T1','T2','T3','location','EastOutside')

subplot(2,1,2), plot(x,k(:,1),'r',x,k(:,2),'b',x,k(:,3),'g')
xlabel('time [s]','fontsize',16)
ylabel('conductivity [W/mK]','fontsize',16)
title(['Thermal Conductivity calculated between ', num2str(x(1)),' and ', num2str(x(length(x))),' s'],'fontsize',16)
legend(['k, T1-T2, k_{mean} = ' num2str(mean(k(:,1)))],['k, T2-T3, k_{mean} = ' num2str(mean(k(:,2)))],['k, T1-T3, k_{mean} = ' num2str(mean(k(:,3)))],'location','EastOutside')

disp('Average Temperatures for Conductivity Calculation:')
disp(mean(T,1))
