% Plot uncertainties, one variable at the time   

% uncertainty_cond(d_T,r,h,Q,dr,dT,dQ,dh)
clc
clear all
close all
% Input Values
% Temperature
T = [66.214   63.092]; % [K]
r = [8.25E-3 13.91e-3]; % [m]
h = 0.1; % [m]
Q = 1.1328; % [W]

% D = 0.0045; %inside diameter heater
% q_flux = 1100;

% A_s = D*pi*h;
% Q = q_flux*A_s
d_T = T(1)-T(2);

% Uncertainities, plots the uncertainty from 0 to the maximum defined below
dr = .00021;
dT = 0.1;
dQ = 0.025;
dh = 0.005;

% Number of steps between maximum and minimum
n = 10;

% Nominal Value
k(1:n+1) = -Q/(2*pi*h)*log(r(2)/r(1))/(T(2)-T(1));

disp('Nominal Conductivity:')
disp(k(1))
% dr
if dr~=0
    j = 1;
    for i = 0:dr/n:dr
        E(j) = uncertainty_cond(d_T,r,h,Q,i,dT,dQ,dh);
        E_neg(j) = k(1)-E(j);
        E_pos(j) = k(1)+E(j);
        x(j) = i;
        j = j + 1;       
    end
    
    figure(1)
    plot(x,E_neg,'b',x,E_pos,'b',x,k,'r','LineWidth',1)
    grid on
    xlabel('\delta r','fontsize',20)
    ylabel('k','fontsize',20)
    legend('Uncertainty','Location','NorthWest')
end

% dT
if dT~=0
    j = 1;
    for i = 0:dT/n:dT
        E(j) = uncertainty_cond(d_T,r,h,Q,dr,i,dQ,dh);
        E_neg(j) = k(1)-E(j);
        E_pos(j) = k(1)+E(j);
        x(j) = i;
        j = j + 1;       
    end
    
    figure(2)
    plot(x,E_neg,'b',x,E_pos,'b',x,k,'r','LineWidth',1)
    grid on
    xlabel('\delta T','fontsize',20)
    ylabel('k','fontsize',20)
    legend('Uncertainty','Location','NorthWest')
end

% dQ
if dQ~=0
    j = 1;
    for i = 0:dQ/n:dQ
        E(j) = uncertainty_cond(d_T,r,h,Q,dr,dT,i,dh);
        E_neg(j) = k(1)-E(j);
        E_pos(j) = k(1)+E(j);
        x(j) = i;
        j = j + 1;       
    end
    
    figure(3)
    plot(x,E_neg,'b',x,E_pos,'b',x,k,'r','LineWidth',1)
    grid on
    xlabel('\delta Q','fontsize',20)
    ylabel('k','fontsize',20)
    legend('Uncertainty','Location','NorthWest')
end

% dh
if dh~=0
    j = 1;
    for i = 0:dh/n:dh
        E(j) = uncertainty_cond(d_T,r,h,Q,dr,dT,dQ,i);
        E_neg(j) = k(1)-E(j);
        E_pos(j) = k(1)+E(j);
        x(j) = i;
        j = j + 1;       
    end
    
    figure(4)
    plot(x,E_neg,'b',x,E_pos,'b',x,k,'r','LineWidth',1)
    grid on
    xlabel('\delta h','fontsize',20)
    ylabel('k','fontsize',20)
    legend('Uncertainty','Location','NorthWest')
end
disp('Uncertainty:')
disp(uncertainty_cond(d_T,r,h,Q,dr,dT,dQ,dh))
disp('Percent:')
disp((uncertainty_cond(d_T,r,h,Q,dr,dT,dQ,dh))/k(1)*100)
