% Permability Calculator
close all
clear all
clc


%Uncertainties
ddP = 7; %differentialpressure full scale accuracy +-7Pa
dL = 2e-3; %length uncertainty +-5mm
dmu = .025e-5; %uncertainty viscosity

rho = 1.204;%air 20degC
% Re_1
d_gr = 0.9e-3;
phi = .75;
eps = 0.36;
d_el = phi*d_gr;
B = 1.8; %1.8 bodies smooth surface, 4.0 bodies rough surface
g = 9.81; %[m/s^2]
T_in = 293; 
T_ex = 293;

% With low flow rate and differential pressure, the inaccuracy may increase
% rapidly. The n first measurements can be removed if wanted.
n =0;

% measurement data:
% material = [Q [%] , dP [Pa] , Pgauge [bar] , Float] 
% Float == 1 , 0.05-0.49 l/min
% Float == 2 , 0.42-4.16 l/min
sand1 = [52 13 1 1;
        73 21 1 1;
        27 7 1 1;
        14 3 1 1;
        47 12 1 1;
        35 4 0 1;
        91 15 0 1;
        65 9 0 1;
        37 5 0 1;
        27 3 0 1;
        11 2 0 1;
        100 17 0 1;
        10 22 0 2;
        27 50 0 2;
        50 79 0 2;
        73 112 0 2;
        95 147 0 2;
        9 34 1 2;
        37 91 1 2;
        68 150 1 2;
        96 223 1 2];

sand2 = [12 24 0 2;
        28 50 0 2;
        60 88 0 2;
        90 135 0 2;
        100 155 0 2;
        12 45 1 2;
        32 81 1 2;
        59 129 1 2;
        80 180 1 2;
        92 211 1 2;
        17 67 2 2;
        45 133 2 2;
        76 211 2 2;
        90 257 2 2;
        99 17 0 1;
        67 17 1 1;
        100 31 1 1;
        62 22 2 1;
        93 35 2 1];
    
expancel = [10 315 0 1;
            20 423 0 1;
            30 655 0 1;
            40 940 0 1;
            50 1435 0 1;
            65 1977 0 1;
            75 2326 0 1;
            90 3104 0 1;
            100 3617 0 1];
sugar = [75 28 0 1;
         70 25 0 1;
         97 41 0 1; 
         82 31 0 1;
         25 112 0 2;
         15 72 0 2;
         34 145 0 2;
         51 190 0 2;
         67 240 0 2;
         80 293 0 2;
         90 335 0 2;
         100 371 0 2;
         31 197 1 2;
         49 269 1 2;
         76 407 1 2;
         97 552 1 2;
         81 554 2 2;
         96 668 2 2];


material = expancel;

    T = 23; %[degC]
    L = 0.1; % [m]
    D = 0.04; % [m]
    mu = 1.825e-5; % [kg/ms]
% rotameterpercenttoflow(Float,Percent,Pgauge,Temperature,dP)

K = [];
dQ = [];
material(:,5) = 0;

for i = 1:size(material,1)
    QdQ = rotameterpercenttoflow(material(i,4),material(i,1),material(i,3),T,material(i,2));
    material(i,1) = QdQ(1);
    material(i,5) = QdQ(2);
end

% Sort measurements after actual flow rate: low->high
material = sortrows(material,1);

%Remove the n first measurements
for i = 1:n
    material(1,:) = [];
end

%Uncertainties, uncertainty_perm(D,Q,dP,visc,L,dQ,ddP,dvisc,dL)

dKappa = []; % [dKappa, dKappamean]

kappa = []; % [Q , Kappa, Re, Mean]
for i = 1:size(material,1)
    kappa(i,1) = material(i,1);
    kappa(i,2) = 4*kappa(i,1)/(pi*D^2)*mu*L/material(i,2);
    kappa(i,3) = 4*rho*material(i,1)*phi*d_gr/(pi*D^2*mu);
    
    dKappa(i,1) = uncertainty_perm(D,kappa(i,1),material(i,2),mu,L,material(i,5),ddP,dmu,dL);
end

kappa(:,4) = mean(kappa(:,2));
dKappa(:,2) = mean(dKappa(:,1));


% PLOT

subplot(2,1,1),plot (kappa(:,1)*1e3*60,kappa(:,2),'-b.',kappa(:,1)*1e3*60,kappa(:,4),'-r',kappa(:,1)*1e3*60,kappa(:,2)+dKappa(:,1),'--k.',kappa(:,1)*1e3*60,kappa(:,2)-dKappa(:,1),'--k.')
xlabel('Q [l/min]','fontsize',20)
ylabel('\kappa','fontsize',20)
grid on
legend('Permeability Calculation',['Average = ',num2str(kappa(1,4)),' m^2', ],'Individual Uncertainty')
% figure(2)
% semilogx (kappa(:,1),kappa(:,2))
% grid on
% xlabel('Q')
% ylabel('\kappa')

disp('Mean Permeability:')
disp([num2str(mean(kappa(:,2))), ' +- ' ,num2str(mean(dKappa(:,1)))])
disp(mean(dKappa(:,1))/mean(kappa(:,2)))


subplot(2,1,2),plot(kappa(:,1)*1e3*60,dKappa(:,1)./kappa(:,2),'-g.')
grid on
xlabel('Q [l/min]','fontsize',20)
ylabel('\delta \kappa / \kappa','fontsize',20)

figure(2)
semilogx (kappa(:,3),kappa(:,2),'-b.',kappa(:,3),kappa(:,4),'-r')
grid on

perm = [];
Re = [];
i  = 1;
for w = 0:.0001:1
    perm(i,1) = idelchikperma(w,L,D,d_gr,phi,eps,B,T_in,T_ex,mu,rho);
    Re(i,1) = w*d_el*rho/mu;

    i = i + 1;
end
hold on
semilogx(Re,perm)
grid on
xlabel('Re_1','fontsize',20)
ylabel('\kappa','fontsize',20)
legend('Measured',['Average = ',num2str(kappa(1,4)),' m^2'],['Estimation, d_{gr} = ',num2str(d_gr),'m, \epsilon = ',num2str(eps),', \phi = ',num2str(phi),' , Smooth'],'Location','SouthWest')

flowdP = [material(:,1)*1000*60, material(:,2)];
disp('Flow Rate [l/min] , dP :')
disp(flowdP)

    
    
    
