function Q = rotameterpercenttoflow(Float,Percent,Pgauge,Temperature,dP)
%Calculates flow in [m^3/s] from rotameter readings
%Float == 1 , 0.05-0.49 l/min
%Float == 2 , 0.42-4.16 l/min

%Reference Case:
atm = 101325; % [Pa]
T_ref = 293; %[K]
P_ref = atm; %[Pa]
R = .287E3; %[J/(kgK)] air

if Float == 1
    Q_min_ref = 0.05; %[l/min]
    Q_max_ref = 0.49; %[l/min]
elseif Float == 2
    Q_min_ref = 0.42; %[l/min]
    Q_max_ref = 4.16; %[l/min]
else
    disp('Error');
end
    
rho_ref = P_ref/(R*T_ref);
C_min = Q_min_ref*sqrt(rho_ref);
C_max = Q_max_ref*sqrt(rho_ref);

rho_before_loss = (P_ref+dP)/(R*T_ref);

P = atm + Pgauge*1e5;
rho = P/(R*(Temperature+273));

Q_min = C_min/sqrt(rho);
Q_max = C_max/sqrt(rho);

Q_ = (Q_max-Q_min)*Percent/100+Q_min; %[l/min]
m = Q_*1e-3/60*rho; %[kg/s]
Q = m/(rho_before_loss+rho_ref)*2;

P4 = atm;
X = Percent;
T = Temperature+273;

%Uncertainties
dP4 = 1000;
ddP = 7;
if Pgauge ~= 0
    dPgauge = 1e4;
else
    dPgauge = 0;
end

dR = 15;
dT = 3;
dX = 3;

dQ = uncertaintyQ(P4,dP,Pgauge,R,T,X,dP4,ddP,dPgauge,dR,dT,dX,C_min,C_max);

Q(1) = Q;
Q(2) = dQ;
return











