% Plot uncertainties, one variable at the time
% uncertainty_perm(D,Q,dP,visc,L,rho,dQ,ddP,dvisc,dL,drho)
clc
clear all
close all
% Input Values
dP = 33.3; %[Pa]
L = 0.1; %[m]
rho = 1.204; %[kg/m^3]
mu = 1.825E-5; %[Pa*s]
D = .04; %[m]
Q = 1.6709e-5; %[m^3/s]
g = 9.81; %[m/s^2]

% Uncertainities, plots the uncertainty from 0 to the maximum defined below
ddP = 5;
dmu = 0.1e-5;
dQ = 0.1667e-5;
dL = 0.005;
drho = 0.0;

% Number of steps between maximum and minimum
n = 10;

% Nominal Value
k(1:n+1) = 4*Q*mu/(pi*D^2*(dP/L));

disp('Nominal Permeability:')
disp(k(1))
% ddP
if ddP~=0
    j = 1;
    for i = 0:ddP/n:ddP
        E(j) = uncertainty_perm(D,Q,dP,mu,L,dQ,i,dmu,dL);
        E_neg(j) = k(1)-E(j);
        E_pos(j) = k(1)+E(j);
        x(j) = i;
        j = j + 1;       
    end
    
    figure(1)
    plot(x,E_neg,'b',x,E_pos,'b',x,k,'r','LineWidth',1)
    grid on
    xlabel('\delta \Delta P','fontsize',20)
    ylabel('\kappa','fontsize',20)
    legend('Uncertainty','Location','NorthWest')
end

% dmu
if dmu~=0
    j = 1;
    for i = 0:dmu/n:dmu
        E(j) = uncertainty_perm(D,Q,dP,mu,L,dQ,ddP,i,dL);
        E_neg(j) = k(1)-E(j);
        E_pos(j) = k(1)+E(j);
        x(j) = i;
        j = j + 1;       
    end
    
    figure(2)
    plot(x,E_neg,'b',x,E_pos,'b',x,k,'r','LineWidth',1)
    grid on
    xlabel('\delta \mu','fontsize',20)
    ylabel('\kappa','fontsize',20)
    legend('Uncertainty','Location','NorthWest')
end

% dQ
if dQ~=0
    j = 1;
    for i = 0:dQ/n:dQ
        E(j) = uncertainty_perm(D,Q,dP,mu,L,i,ddP,dmu,dL);
        E_neg(j) = k(1)-E(j);
        E_pos(j) = k(1)+E(j);
        x(j) = i;
        j = j + 1;       
    end
    
    figure(3)
    plot(x,E_neg,'b',x,E_pos,'b',x,k,'r','LineWidth',1)
    grid on
    xlabel('\delta Q','fontsize',20)
    ylabel('\kappa','fontsize',20)
    legend('Uncertainty','Location','NorthWest')
end

% dL
if dL~=0
    j = 1;
    for i = 0:dL/n:dL
        E(j) = uncertainty_perm(D,Q,dP,mu,L,dQ,ddP,dmu,i);
        E_neg(j) = k(1)-E(j);
        E_pos(j) = k(1)+E(j);
        x(j) = i;
        j = j + 1;       
    end
    
    figure(4)
    plot(x,E_neg,'b',x,E_pos,'b',x,k,'r','LineWidth',1)
    grid on
    xlabel('\delta L','fontsize',20)
    ylabel('\kappa','fontsize',20)
    legend('Uncertainty','Location','NorthWest')
end

% drho
if drho~=0
    j = 1;
    for i = 0:drho/n:drho
        E(j) = uncertainty_perm(D,Q,dP,mu,L,dQ,ddP,dmu,dL);
        E_neg(j) = k(1)-E(j);
        E_pos(j) = k(1)+E(j);
        x(j) = i;
        j = j + 1;       
    end
    
    figure(5)
    plot(x,E_neg,'b',x,E_pos,'b',x,k,'r','LineWidth',1)
    grid on
    xlabel('\delta \rho','fontsize',20)
    ylabel('\kappa','fontsize',20)
    legend('Uncertainty','Location','NorthWest')
end
disp('Uncertainty:')
disp(uncertainty_perm(D,Q,dP,mu,L,dQ,ddP,dmu,dL))
disp('Percent:')
disp((uncertainty_perm(D,Q,dP,mu,L,dQ,ddP,dmu,dL))/k(1)*100)
